@@ -56,10 +56,10 @@ class Command:
             self.conditions[type] = {}
 
     def commands_list(self):
-        return [command.keys() for command in self.commands["command"].keys()]
+        return [command for command in self.commands["command"].keys()]
 
     def answer_list(self):
-        return [command.keys() for command in self.commands["answser"].keys()]
+        return [command for command in self.commands["answser"].keys()]
 
     def command(self, name=None, condition=None):
         type = "command"
@@ -221,11 +221,11 @@ class BannedWords:
                 para = self.filtre_message(args.message, word).split()
                 if para != [""]:
                     with suppress(Exception):
-                        [args.subClient.delete_message(args.chatId, args.messageId, reason="Banned word", asStaff=True) for elem in para if elem in args.subClient.banned_words]
+                        [args.subClient.delete_message(args.chatId, args.messageId, reason=f"Banned word : {elem}", asStaff=True) for elem in para if elem in args.subClient.banned_words]
 
 
 class Parameters:
-    __slots__ = ("subClient", "chatId", "authorId", "author", "message", "messageId", "info")
+    __slots__ = ("subClient", "chatId", "authorId", "author", "message", "messageId", "comId", "info")
 
     def __init__(self, data, subClient):
         self.subClient = subClient
@@ -234,6 +234,7 @@ class Parameters:
         self.author = data.message.author.nickname
         self.message = data.message.content
         self.messageId = data.message.messageId
+        self.comId = data.comId
         self.info = data
 
 
@@ -338,7 +339,7 @@ class BotAmino(Command, Client, TimeOut, BannedWords):
 
     def message_analyse(self, data, type):
         try:
-            commuId = data.json["ndcId"]
+            commuId = data.comId
             subClient = self.get_community(commuId)
         except Exception:
             return
@@ -348,7 +349,7 @@ class BotAmino(Command, Client, TimeOut, BannedWords):
 
     def on_member_event(self, data, type):
         try:
-            commuId = data.json["ndcId"]
+            commuId = data.comId
             subClient = self.get_community(commuId)
         except Exception:
             return
@@ -361,7 +362,7 @@ class BotAmino(Command, Client, TimeOut, BannedWords):
     def launch_text_message(self):
         def text_message(data):
             try:
-                commuId = data.json["ndcId"]
+                commuId = data.comId
                 subClient = self.get_community(commuId)
             except Exception:
                 return
@@ -551,7 +552,8 @@ class Bot(SubClient, ACM):
         return {"welcome": "", "prefix": self.prefix, "welcome_chat": "", "favorite_users": [], "favorite_chats": [], "banned_words": []}
 
     def get_dict(self):
-        return {"welcome": self.message_bvn, "prefix": self.prefix, "welcome_chat": self.welcome_chat, "favorite_users": self.favorite_users, "favorite_chats": self.favorite_chats, "banned_words": self.banned_words}
+        return {"welcome": self.message_bvn, "prefix": self.prefix, "welcome_chat": self.welcome_chat,
+                "favorite_users": self.favorite_users, "favorite_chats": self.favorite_chats, "banned_words": self.banned_words}
 
     def update_file(self, dict=None):
         if not dict:
@@ -881,7 +883,7 @@ class Bot(SubClient, ACM):
             timeEnd = timeNow + 300
             try:
                 self.send_active_obj(startTime=timeNow, endTime=timeEnd)
-            except Exception as activeError:
+            except Exception:
                 pass
 
         def change_bio_and_welcome_members():
